@@ -19,8 +19,10 @@ from __future__ import print_function
 import argparse
 import logging
 import sys
+import warnings
 
 from oslo_utils import encodeutils
+from oslo_utils import importutils
 import six
 
 import ceilometerclient
@@ -112,22 +114,13 @@ class CeilometerShell(object):
 
         self.subcommands = {}
         subparsers = parser.add_subparsers(metavar='<subcommand>')
-        submodule = utils.import_versioned_module(version, 'shell')
+        submodule = importutils.import_versioned_module('ceilometerclient',
+                                                        version, 'shell')
         self._find_actions(subparsers, submodule)
         self._find_actions(subparsers, self)
-        self._add_bash_completion_subparser(subparsers)
 
         return parser
 
-    def _add_bash_completion_subparser(self, subparsers):
-        subparser = subparsers.add_parser(
-            'bash_completion',
-            add_help=False,
-            formatter_class=HelpFormatter
-        )
-        self.subcommands['bash_completion'] = subparser
-        subparser.set_defaults(func=self.do_bash_completion)
-
     def _find_actions(self, subparsers, actions_module):
         for attr in (a for a in dir(actions_module) if a.startswith('do_')):
             # I prefer to be hypen-separated instead of underscores.
@@ -179,16 +172,11 @@ class CeilometerShell(object):
         # Return parsed args
         return api_version, subcommand_parser.parse_args(argv)
 
-    @staticmethod
-    def no_project_and_domain_set(args):
-        if not (args.os_project_id or (args.os_project_name and
-                (args.os_user_domain_name or args.os_user_domain_id)) or
-                (args.os_tenant_id or args.os_tenant_name)):
-            return True
-        else:
-            return False
-
     def main(self, argv):
+        warnings.warn(
+            "ceilometerclient is now deprecated as the Ceilometer API has "
+            "been deprecated. Please use either aodhclient, pankoclient or "
+            "gnocchiclient.")
         parsed = self.parse_args(argv)
         if parsed == 0:
             return 0
@@ -215,17 +203,12 @@ class CeilometerShell(object):
                                        "either --os-password or via "
                                        "env[OS_PASSWORD]")
 
-            if self.no_project_and_domain_set(args):
+            if not (args.os_project_id or args.os_project_name
+                    or args.os_tenant_id or args.os_tenant_name):
                 # steer users towards Keystone V3 API
-                raise exc.CommandError("You must provide a project_id via "
-                                       "either --os-project-id or via "
-                                       "env[OS_PROJECT_ID] and "
-                                       "a domain_name via either "
-                                       "--os-user-domain-name or via "
-                                       "env[OS_USER_DOMAIN_NAME] or "
-                                       "a domain_id via either "
-                                       "--os-user-domain-id or via "
-                                       "env[OS_USER_DOMAIN_ID]")
+                raise exc.CommandError("You must provide a project_id "
+                                       "(or name) via either --os-project-id "
+                                       "or via env[OS_PROJECT_ID]")
 
             if not self.auth_plugin.opts['auth_url']:
                 raise exc.CommandError("You must provide an auth url via "
@@ -255,7 +238,6 @@ class CeilometerShell(object):
                 options.add(option)
 
         commands.remove('bash-completion')
-        commands.remove('bash_completion')
         print(' '.join(commands | options))
 
     @utils.arg('command', metavar='<subcommand>', nargs='?',
